test

package
v1.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 6, 2019 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AssertEqual

func AssertEqual(subject string, expect string, actual string, t *testing.T)

AssertEqual asserts that two strings are equal.

func AssertError

func AssertError(expect string, err error, t *testing.T)

AssertError asserts that an error has the expected value.

func AssertGetterValue

func AssertGetterValue(subject string, expect string, f func() (string, error), t *testing.T)

AssertGetterValue asserts that the return value of a getter function is as expected.

func AssertIsInvalid

func AssertIsInvalid(expect string, valid bool, reason string, t *testing.T)

AssertIsInvalid asserts that the result of an IsValid() call indicates that the value is invalid.

func AssertIsValid

func AssertIsValid(valid bool, reason string, t *testing.T)

AssertIsValid asserts that the result of an IsValid() call indicates that the value is valid.

func AssertNoError

func AssertNoError(err error, t *testing.T)

AssertNoError asserts that an error is nil.

Types

This section is empty.

Jump to