Documentation
¶
Index ¶
- func AssertEqual(subject string, expect string, actual string, t *testing.T)
- func AssertError(expect string, err error, t *testing.T)
- func AssertGetterValue(subject string, expect string, f func() (string, error), t *testing.T)
- func AssertIsInvalid(expect string, valid bool, reason string, t *testing.T)
- func AssertIsValid(valid bool, reason string, t *testing.T)
- func AssertNoError(err error, t *testing.T)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AssertEqual ¶
AssertEqual asserts that two strings are equal.
func AssertError ¶
AssertError asserts that an error has the expected value.
func AssertGetterValue ¶
AssertGetterValue asserts that the return value of a getter function is as expected.
func AssertIsInvalid ¶
AssertIsInvalid asserts that the result of an IsValid() call indicates that the value is invalid.
func AssertIsValid ¶
AssertIsValid asserts that the result of an IsValid() call indicates that the value is valid.
func AssertNoError ¶
AssertNoError asserts that an error is nil.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.